@@ -1,10 +1,10 @@
 from typing import List
+
+import requirements
 from packaging import version
-from pkg_resources import Requirement, parse_requirements
 
 
-class RequirementList(List[Requirement]):
-
+class RequirementList(List):
     @classmethod
     def from_file(cls, filepath):
         """
@@ -12,7 +12,7 @@ class RequirementList(List[Requirement]):
         :rtype: RequirementList
         """
         with open(filepath) as f:
-            return cls(parse_requirements(f.read()))
+            return cls(requirements.parse(f.read()))
 
     def __contains__(self, package_name):
         """
@@ -27,12 +27,13 @@ class RequirementList(List[Requirement]):
         :rtype: Requirement
         """
         for requirement in self:
-            if requirement.key == package_name:
+            if requirement.name == package_name:
                 return requirement
 
     def get_specs(self, package_name):
         """
         :param str package_name:
+        :rtype: typing.List[typing.Optional[str]]
         """
         requirement = self.get(package_name)
         if requirement is not None:
@@ -41,6 +42,7 @@ class RequirementList(List[Requirement]):
     def get_version(self, package_name):
         """
         :param str package_name:
+        :rtype: typing.Optional[packaging.version.Version]
         """
         specs = self.get_specs(package_name)
         if specs:
